@@ -1,4 +1,4 @@
-def line(x,y,z,vectX,vectY,vectZ,norme,name='vect',large=0.3,color=[0.4, 1.0, 0.0]):
+def line(x,y,z,vectX,vectY,vectZ,norme,name='vect',large=0.3,color=[0.4, 1.0, 0.0],selectedColor=[1.0, 0.5000076295109484, 0.5000076295109484]):
     dLine={
             "type": "Line",
             "coordinateSystem": "LPS",
@@ -42,7 +42,7 @@ def line(x,y,z,vectX,vectY,vectZ,norme,name='vect',large=0.3,color=[0.4, 1.0, 0.
                 "visibility": True,
                 "opacity": 1.0,
                 "color": color,
-                "selectedColor": [1.0, 0.5000076295109484, 0.5000076295109484],
+                "selectedColor": selectedColor,
                 "activeColor": [0.4, 1.0, 0.0],
                 "propertiesLabelVisibility": True,
                 "pointLabelsVisibility": False,
@@ -67,7 +67,7 @@ def line(x,y,z,vectX,vectY,vectZ,norme,name='vect',large=0.3,color=[0.4, 1.0, 0.
         }
     return dLine
 
-def point(x,y,z,name="point",large=5.0,color=[0.4, 1.0, 0.0]):
+def point(x,y,z,name="point",large=5.0,color=[0.4, 1.0, 0.0],selectedColor=[1.0, 0.5000076295109484, 0.5000076295109484]):
     dPoint={
             "type": "Fiducial",
             "coordinateSystem": "LPS",
@@ -92,7 +92,7 @@ def point(x,y,z,name="point",large=5.0,color=[0.4, 1.0, 0.0]):
                 "visibility": True,
                 "opacity": 1.0,
                 "color": color,
-                "selectedColor": [1.0, 0.5000076295109484, 0.5000076295109484],
+                "selectedColor": selectedColor,
                 "activeColor": [0.4, 1.0, 0.0],
                 "propertiesLabelVisibility": False,
                 "pointLabelsVisibility": True,
